#!/usr/bin/perl -I /usr/sausalito/perl
# $Id: whitebox.pl,v 1.6 2001/07/27 19:40:12 will Exp $
# Copyright 2000, 2001 Sun Microsystems, Inc., All rights reserved.
# Cobalt Linux White Box Converter
#
# Disables automated management and configuration utilities
# included in this distribution of Cobalt Linux.
# 
# Primary functions of this script are to:
# - disable administrative daemons (admserv, cced)
# - disable Cobalt Linux Active Monitoring
# - activate all registered whitebox conversion scripts
#   in /etc/cobalt/whitebox.d/
#
# whitebox.d is owned by base-services.mod 

my $DEBUG = 0;
my $destruct = 1; 	# boolean self-destruct : resurrect
			# Never resurrect managed Cobalt Linux tools
			# as the system will not be consistent with
			# what is represented in the GUI.

# The following daemon scripts are abrubtly removed from the gene pool.
my @daemon_initscripts = (
	'admserv', 'cced.init'
	);

my $chkconfig_bin = '/sbin/chkconfig';
my $init_dir = '/etc/rc.d/init.d';
my $crontab = '/etc/crontab';
my $crontab_init = "$init_dir/crond";
my $swatch = 'swatch';
my $whitebox_dir = '/etc/cobalt/whitebox.d';

use I18n;
my $i18n = new I18n;
$i18n->setLocale(I18n::i18n_getSystemLocale());

# FIXME: add warning

use Sauce::Util;
# Disable swatch
Sauce::Util::editfile($crontab, \&edit_crontab, $destruct) ||
	warn "Could not find swatch crontab entry in /etc/crontab\n";
my $out = `$crontab_init reload 2>&1`;
$DEBUG && warn "Stopped swatch, reloaded cron: $out";

# Down system daemons
my $daemon;
foreach $daemon (@daemon_initscripts)
{
	my $opt = '--add';
	$opt = '--del' if ($destruct);
	$DEBUG && warn "Configuring daemon: $daemon\n";
	my $out = `$chkconfig_bin $opt $daemon`;
	$DEBUG && warn "chkconfig $opt $daemon output: $out\n";

	my $arg = 'restart';
	$arg = 'stop' if ($destruct);
	$out = `$init_dir/$daemon $arg`;
	$DEBUG && warn "init script \"stop\" output: $out\n";
}

# Process whitebox.d scripts
if(-d $whitebox_dir)
{
	my ($scriptlet, @wb);
	opendir(WBD, $whitebox_dir) || die 
		"Could not read the whitebox directory: $whitebox_dir: $!";
	while($scriptlet = readdir(WBD))
	{
		next if ($scriptlet =~ /^\.+$/);
		next unless (-x "$whitebox_dir/$scriptlet");
		push(@wb, $scriptlet);
	}
	closedir(WBD);
	foreach $scriptlet (sort @wb)
	{
		my $arg = 'resurrect';
		$arg = 'destruct' if ($destruct);
		$DEBUG && warn "Executing $scriptlet with argument \"$arg\"...\n";
		system("$whitebox_dir/$scriptlet $arg");
	}
}
else
{
	$DEBUG && warn "No whitebox script repository at $whitebox_dir.  Skipping.\n";
}

print "Fin!\n";
exit(0);

# Subs

sub edit_crontab
{
	my($in, $out, $destruct) = @_;
	my $ret = 0;
	while(<$in>)
	{
		if(/\/$swatch\s+/)
		{
			unless($destruct)
			{
				$_ =~ s/^\s*\#\s*//g;
				$ret = 1;
			}
			else
			{
				$_ = '# '.$_ unless (/^\s*\#/);
				$ret = 1;
			}
			print $out $_;
		}
		else
		{
			print $out $_;
		}
	}
	return $ret;
}

